class AAR:
    ISO_639_1 = ''
    ISO_639 = 'aar'
    ENGLISH_NAME = 'Afar'


class ABK:
    ISO_639_1 = ''
    ISO_639 = 'abk'
    ENGLISH_NAME = 'Abkhazian'


class ACE:
    ISO_639_1 = ''
    ISO_639 = 'ace'
    ENGLISH_NAME = 'Achinese'


class ACH:
    ISO_639_1 = ''
    ISO_639 = 'ach'
    ENGLISH_NAME = 'Acoli'


class ADA:
    ISO_639_1 = ''
    ISO_639 = 'ada'
    ENGLISH_NAME = 'Adangme'


class ADY:
    ISO_639_1 = ''
    ISO_639 = 'ady'
    ENGLISH_NAME = 'Adyghe'


class AFH:
    ISO_639_1 = ''
    ISO_639 = 'afh'
    ENGLISH_NAME = 'Afrihili'


class AFR:
    ISO_639_1 = ''
    ISO_639 = 'afr'
    ENGLISH_NAME = 'Afrikaans'


class AIN:
    ISO_639_1 = ''
    ISO_639 = 'ain'
    ENGLISH_NAME = 'Ainu'


class AKA:
    ISO_639_1 = ''
    ISO_639 = 'aka'
    ENGLISH_NAME = 'Akan'


class AKK:
    ISO_639_1 = ''
    ISO_639 = 'akk'
    ENGLISH_NAME = 'Akkadian'


class ALB:
    ISO_639_1 = ''
    ISO_639 = 'alb'
    ENGLISH_NAME = 'Albanian'


class ALE:
    ISO_639_1 = ''
    ISO_639 = 'ale'
    ENGLISH_NAME = 'Aleut'


class ALT:
    ISO_639_1 = ''
    ISO_639 = 'alt'
    ENGLISH_NAME = 'SouthernAltai'


class AMH:
    ISO_639_1 = ''
    ISO_639 = 'amh'
    ENGLISH_NAME = 'Amharic'


class ANP:
    ISO_639_1 = ''
    ISO_639 = 'anp'
    ENGLISH_NAME = 'Angika'


class ARA:
    ISO_639_1 = ''
    ISO_639 = 'ara'
    ENGLISH_NAME = 'Arabic'


class ARG:
    ISO_639_1 = ''
    ISO_639 = 'arg'
    ENGLISH_NAME = 'Aragonese'


class ARM:
    ISO_639_1 = ''
    ISO_639 = 'arm'
    ENGLISH_NAME = 'Armenian'


class ARN:
    ISO_639_1 = ''
    ISO_639 = 'arn'
    ENGLISH_NAME = 'Mapudungun'


class ARP:
    ISO_639_1 = ''
    ISO_639 = 'arp'
    ENGLISH_NAME = 'Arapaho'


class ARW:
    ISO_639_1 = ''
    ISO_639 = 'arw'
    ENGLISH_NAME = 'Arawak'


class ASM:
    ISO_639_1 = ''
    ISO_639 = 'asm'
    ENGLISH_NAME = 'Assamese'


class AST:
    ISO_639_1 = ''
    ISO_639 = 'ast'
    ENGLISH_NAME = 'Asturian'


class AVA:
    ISO_639_1 = ''
    ISO_639 = 'ava'
    ENGLISH_NAME = 'Avaric'


class AVE:
    ISO_639_1 = ''
    ISO_639 = 'ave'
    ENGLISH_NAME = 'Avestan'


class AWA:
    ISO_639_1 = ''
    ISO_639 = 'awa'
    ENGLISH_NAME = 'Awadhi'


class AYM:
    ISO_639_1 = ''
    ISO_639 = 'aym'
    ENGLISH_NAME = 'Aymara'


class AZE:
    ISO_639_1 = ''
    ISO_639 = 'aze'
    ENGLISH_NAME = 'Azerbaijani'


class BAK:
    ISO_639_1 = ''
    ISO_639 = 'bak'
    ENGLISH_NAME = 'Bashkir'


class BAL:
    ISO_639_1 = ''
    ISO_639 = 'bal'
    ENGLISH_NAME = 'Baluchi'


class BAM:
    ISO_639_1 = ''
    ISO_639 = 'bam'
    ENGLISH_NAME = 'Bambara'


class BAN:
    ISO_639_1 = ''
    ISO_639 = 'ban'
    ENGLISH_NAME = 'Balinese'


class BAQ:
    ISO_639_1 = ''
    ISO_639 = 'baq'
    ENGLISH_NAME = 'Basque'


class BAS:
    ISO_639_1 = ''
    ISO_639 = 'bas'
    ENGLISH_NAME = 'Basa'


class BEJ:
    ISO_639_1 = ''
    ISO_639 = 'bej'
    ENGLISH_NAME = 'Beja'


class BEL:
    ISO_639_1 = ''
    ISO_639 = 'bel'
    ENGLISH_NAME = 'Belarusian'


class BEM:
    ISO_639_1 = ''
    ISO_639 = 'bem'
    ENGLISH_NAME = 'Bemba'


class BEN:
    ISO_639_1 = 'bn'
    ISO_639 = 'ben'
    ENGLISH_NAME = 'Bengali'


class BHO:
    ISO_639_1 = ''
    ISO_639 = 'bho'
    ENGLISH_NAME = 'Bhojpuri'


class BIK:
    ISO_639_1 = ''
    ISO_639 = 'bik'
    ENGLISH_NAME = 'Bikol'


class BIN:
    ISO_639_1 = ''
    ISO_639 = 'bin'
    ENGLISH_NAME = 'Bini'


class BIS:
    ISO_639_1 = ''
    ISO_639 = 'bis'
    ENGLISH_NAME = 'Bislama'


class BLA:
    ISO_639_1 = ''
    ISO_639 = 'bla'
    ENGLISH_NAME = 'Siksika'


class BOS:
    ISO_639_1 = ''
    ISO_639 = 'bos'
    ENGLISH_NAME = 'Bosnian'


class BRA:
    ISO_639_1 = ''
    ISO_639 = 'bra'
    ENGLISH_NAME = 'Braj'


class BRE:
    ISO_639_1 = ''
    ISO_639 = 'bre'
    ENGLISH_NAME = 'Breton'


class BUA:
    ISO_639_1 = ''
    ISO_639 = 'bua'
    ENGLISH_NAME = 'Buriat'


class BUG:
    ISO_639_1 = ''
    ISO_639 = 'bug'
    ENGLISH_NAME = 'Buginese'


class BUL:
    ISO_639_1 = ''
    ISO_639 = 'bul'
    ENGLISH_NAME = 'Bulgarian'


class BUR:
    ISO_639_1 = ''
    ISO_639 = 'bur'
    ENGLISH_NAME = 'Burmese'


class BYN:
    ISO_639_1 = ''
    ISO_639 = 'byn'
    ENGLISH_NAME = 'Blin'


class CAD:
    ISO_639_1 = ''
    ISO_639 = 'cad'
    ENGLISH_NAME = 'Caddo'


class CAR:
    ISO_639_1 = ''
    ISO_639 = 'car'
    ENGLISH_NAME = 'GalibiCarib'


class CAT:
    ISO_639_1 = ''
    ISO_639 = 'cat'
    ENGLISH_NAME = 'Catalan'


class CEB:
    ISO_639_1 = ''
    ISO_639 = 'ceb'
    ENGLISH_NAME = 'Cebuano'


class CHA:
    ISO_639_1 = ''
    ISO_639 = 'cha'
    ENGLISH_NAME = 'Chamorro'


class CHB:
    ISO_639_1 = ''
    ISO_639 = 'chb'
    ENGLISH_NAME = 'Chibcha'


class CHE:
    ISO_639_1 = ''
    ISO_639 = 'che'
    ENGLISH_NAME = 'Chechen'


class CHG:
    ISO_639_1 = ''
    ISO_639 = 'chg'
    ENGLISH_NAME = 'Chagatai'


class CHI:
    ISO_639_1 = 'zh'
    ISO_639 = 'chi'
    ENGLISH_NAME = 'Chinese'


class CHK:
    ISO_639_1 = ''
    ISO_639 = 'chk'
    ENGLISH_NAME = 'Chuukese'


class CHM:
    ISO_639_1 = ''
    ISO_639 = 'chm'
    ENGLISH_NAME = 'Mari'


class CHN:
    ISO_639_1 = ''
    ISO_639 = 'chn'
    ENGLISH_NAME = 'Chinookjargon'


class CHO:
    ISO_639_1 = ''
    ISO_639 = 'cho'
    ENGLISH_NAME = 'Choctaw'


class CHP:
    ISO_639_1 = ''
    ISO_639 = 'chp'
    ENGLISH_NAME = 'Chipewyan'


class CHR:
    ISO_639_1 = ''
    ISO_639 = 'chr'
    ENGLISH_NAME = 'Cherokee'


class CHV:
    ISO_639_1 = ''
    ISO_639 = 'chv'
    ENGLISH_NAME = 'Chuvash'


class CHY:
    ISO_639_1 = ''
    ISO_639 = 'chy'
    ENGLISH_NAME = 'Cheyenne'


class CNR:
    ISO_639_1 = ''
    ISO_639 = 'cnr'
    ENGLISH_NAME = 'Montenegrin'


class COP:
    ISO_639_1 = ''
    ISO_639 = 'cop'
    ENGLISH_NAME = 'Coptic'


class COR:
    ISO_639_1 = ''
    ISO_639 = 'cor'
    ENGLISH_NAME = 'Cornish'


class COS:
    ISO_639_1 = ''
    ISO_639 = 'cos'
    ENGLISH_NAME = 'Corsican'


class CPE:
    ISO_639_1 = ''
    ISO_639 = 'cpe'
    ENGLISH_NAME = 'Creolesandpidgins'


class CPF:
    ISO_639_1 = ''
    ISO_639 = 'cpf'
    ENGLISH_NAME = 'Creolesandpidgins'


class CPP:
    ISO_639_1 = ''
    ISO_639 = 'cpp'
    ENGLISH_NAME = 'Creolesandpidgins'


class CRE:
    ISO_639_1 = ''
    ISO_639 = 'cre'
    ENGLISH_NAME = 'Cree'


class CRH:
    ISO_639_1 = ''
    ISO_639 = 'crh'
    ENGLISH_NAME = 'CrimeanTatar'


class CRP:
    ISO_639_1 = ''
    ISO_639 = 'crp'
    ENGLISH_NAME = 'Creolesandpidgins'


class CSB:
    ISO_639_1 = ''
    ISO_639 = 'csb'
    ENGLISH_NAME = 'Kashubian'


class CZE:
    ISO_639_1 = ''
    ISO_639 = 'cze'
    ENGLISH_NAME = 'Czech'


class DAK:
    ISO_639_1 = ''
    ISO_639 = 'dak'
    ENGLISH_NAME = 'Dakota'


class DAN:
    ISO_639_1 = ''
    ISO_639 = 'dan'
    ENGLISH_NAME = 'Danish'


class DAR:
    ISO_639_1 = ''
    ISO_639 = 'dar'
    ENGLISH_NAME = 'Dargwa'


class DEL:
    ISO_639_1 = ''
    ISO_639 = 'del'
    ENGLISH_NAME = 'Delaware'


class DEN:
    ISO_639_1 = ''
    ISO_639 = 'den'
    ENGLISH_NAME = 'Slave'


class DGR:
    ISO_639_1 = ''
    ISO_639 = 'dgr'
    ENGLISH_NAME = 'Dogrib'


class DIN:
    ISO_639_1 = ''
    ISO_639 = 'din'
    ENGLISH_NAME = 'Dinka'


class DIV:
    ISO_639_1 = ''
    ISO_639 = 'div'
    ENGLISH_NAME = 'Divehi'


class DOI:
    ISO_639_1 = ''
    ISO_639 = 'doi'
    ENGLISH_NAME = 'Dogri'


class DUA:
    ISO_639_1 = ''
    ISO_639 = 'dua'
    ENGLISH_NAME = 'Duala'


class DUT:
    ISO_639_1 = 'nl'
    ISO_639 = 'dut'
    ENGLISH_NAME = 'Dutch'


class DYU:
    ISO_639_1 = ''
    ISO_639 = 'dyu'
    ENGLISH_NAME = 'Dyula'


class DZO:
    ISO_639_1 = ''
    ISO_639 = 'dzo'
    ENGLISH_NAME = 'Dzongkha'


class EFI:
    ISO_639_1 = ''
    ISO_639 = 'efi'
    ENGLISH_NAME = 'Efik'


class EKA:
    ISO_639_1 = ''
    ISO_639 = 'eka'
    ENGLISH_NAME = 'Ekajuk'


class ELX:
    ISO_639_1 = ''
    ISO_639 = 'elx'
    ENGLISH_NAME = 'Elamite'


class ENG:
    ISO_639_1 = 'en'
    ISO_639 = 'eng'
    ENGLISH_NAME = 'English'


class EPO:
    ISO_639_1 = ''
    ISO_639 = 'epo'
    ENGLISH_NAME = 'Esperanto'


class EST:
    ISO_639_1 = ''
    ISO_639 = 'est'
    ENGLISH_NAME = 'Estonian'


class EWE:
    ISO_639_1 = ''
    ISO_639 = 'ewe'
    ENGLISH_NAME = 'Ewe'


class EWO:
    ISO_639_1 = ''
    ISO_639 = 'ewo'
    ENGLISH_NAME = 'Ewondo'


class FAN:
    ISO_639_1 = ''
    ISO_639 = 'fan'
    ENGLISH_NAME = 'Fang'


class FAO:
    ISO_639_1 = ''
    ISO_639 = 'fao'
    ENGLISH_NAME = 'Faroese'


class FAT:
    ISO_639_1 = ''
    ISO_639 = 'fat'
    ENGLISH_NAME = 'Fanti'


class FIJ:
    ISO_639_1 = ''
    ISO_639 = 'fij'
    ENGLISH_NAME = 'Fijian'


class FIL:
    ISO_639_1 = ''
    ISO_639 = 'fil'
    ENGLISH_NAME = 'Filipino'


class FIN:
    ISO_639_1 = ''
    ISO_639 = 'fin'
    ENGLISH_NAME = 'Finnish'


class FON:
    ISO_639_1 = ''
    ISO_639 = 'fon'
    ENGLISH_NAME = 'Fon'


class FRE:
    ISO_639_1 = ''
    ISO_639 = 'fre'
    ENGLISH_NAME = 'French'


class FRR:
    ISO_639_1 = ''
    ISO_639 = 'frr'
    ENGLISH_NAME = 'NorthernFrisian'


class FRS:
    ISO_639_1 = ''
    ISO_639 = 'frs'
    ENGLISH_NAME = 'EasternFrisian'


class FRY:
    ISO_639_1 = ''
    ISO_639 = 'fry'
    ENGLISH_NAME = 'WesternFrisian'


class FUL:
    ISO_639_1 = ''
    ISO_639 = 'ful'
    ENGLISH_NAME = 'Fulah'


class FUR:
    ISO_639_1 = ''
    ISO_639 = 'fur'
    ENGLISH_NAME = 'Friulian'


class GAA:
    ISO_639_1 = ''
    ISO_639 = 'gaa'
    ENGLISH_NAME = 'Ga'


class GAY:
    ISO_639_1 = ''
    ISO_639 = 'gay'
    ENGLISH_NAME = 'Gayo'


class GBA:
    ISO_639_1 = ''
    ISO_639 = 'gba'
    ENGLISH_NAME = 'Gbaya'


class GEO:
    ISO_639_1 = ''
    ISO_639 = 'geo'
    ENGLISH_NAME = 'Georgian'


class GER:
    ISO_639_1 = 'de'
    ISO_639 = 'ger'
    ENGLISH_NAME = 'German'


class GEZ:
    ISO_639_1 = ''
    ISO_639 = 'gez'
    ENGLISH_NAME = 'Geez'


class GIL:
    ISO_639_1 = ''
    ISO_639 = 'gil'
    ENGLISH_NAME = 'Gilbertese'


class GLA:
    ISO_639_1 = ''
    ISO_639 = 'gla'
    ENGLISH_NAME = 'Gaelic'


class GLE:
    ISO_639_1 = ''
    ISO_639 = 'gle'
    ENGLISH_NAME = 'Irish'


class GLG:
    ISO_639_1 = ''
    ISO_639 = 'glg'
    ENGLISH_NAME = 'Galician'


class GLV:
    ISO_639_1 = ''
    ISO_639 = 'glv'
    ENGLISH_NAME = 'Manx'


class GON:
    ISO_639_1 = ''
    ISO_639 = 'gon'
    ENGLISH_NAME = 'Gondi'


class GOR:
    ISO_639_1 = ''
    ISO_639 = 'gor'
    ENGLISH_NAME = 'Gorontalo'


class GOT:
    ISO_639_1 = ''
    ISO_639 = 'got'
    ENGLISH_NAME = 'Gothic'


class GRB:
    ISO_639_1 = ''
    ISO_639 = 'grb'
    ENGLISH_NAME = 'Grebo'


class GRE:
    ISO_639_1 = 'el'
    ISO_639 = 'gre'
    ENGLISH_NAME = 'Greek'


class GRN:
    ISO_639_1 = ''
    ISO_639 = 'grn'
    ENGLISH_NAME = 'Guarani'


class GSW:
    ISO_639_1 = ''
    ISO_639 = 'gsw'
    ENGLISH_NAME = 'SwissGerman'


class GUJ:
    ISO_639_1 = ''
    ISO_639 = 'guj'
    ENGLISH_NAME = 'Gujarati'


class GWI:
    ISO_639_1 = ''
    ISO_639 = 'gwi'
    ENGLISH_NAME = 'Gwichin'


class HAI:
    ISO_639_1 = ''
    ISO_639 = 'hai'
    ENGLISH_NAME = 'Haida'


class HAT:
    ISO_639_1 = ''
    ISO_639 = 'hat'
    ENGLISH_NAME = 'Haitian'


class HAU:
    ISO_639_1 = ''
    ISO_639 = 'hau'
    ENGLISH_NAME = 'Hausa'


class HAW:
    ISO_639_1 = ''
    ISO_639 = 'haw'
    ENGLISH_NAME = 'Hawaiian'


class HEB:
    ISO_639_1 = 'he'
    ISO_639 = 'heb'
    ENGLISH_NAME = 'Hebrew'


class HER:
    ISO_639_1 = ''
    ISO_639 = 'her'
    ENGLISH_NAME = 'Herero'


class HIL:
    ISO_639_1 = ''
    ISO_639 = 'hil'
    ENGLISH_NAME = 'Hiligaynon'


class HIN:
    ISO_639_1 = 'hi'
    ISO_639 = 'hin'
    ENGLISH_NAME = 'Hindi'


class HIT:
    ISO_639_1 = ''
    ISO_639 = 'hit'
    ENGLISH_NAME = 'Hittite'


class HMN:
    ISO_639_1 = ''
    ISO_639 = 'hmn'
    ENGLISH_NAME = 'Hmong'


class HMO:
    ISO_639_1 = ''
    ISO_639 = 'hmo'
    ENGLISH_NAME = 'HiriMotu'


class HRV:
    ISO_639_1 = ''
    ISO_639 = 'hrv'
    ENGLISH_NAME = 'Croatian'


class HSB:
    ISO_639_1 = ''
    ISO_639 = 'hsb'
    ENGLISH_NAME = 'UpperSorbian'


class HUN:
    ISO_639_1 = ''
    ISO_639 = 'hun'
    ENGLISH_NAME = 'Hungarian'


class HUP:
    ISO_639_1 = ''
    ISO_639 = 'hup'
    ENGLISH_NAME = 'Hupa'


class IBA:
    ISO_639_1 = ''
    ISO_639 = 'iba'
    ENGLISH_NAME = 'Iban'


class IBO:
    ISO_639_1 = ''
    ISO_639 = 'ibo'
    ENGLISH_NAME = 'Igbo'


class ICE:
    ISO_639_1 = ''
    ISO_639 = 'ice'
    ENGLISH_NAME = 'Icelandic'


class IDO:
    ISO_639_1 = ''
    ISO_639 = 'ido'
    ENGLISH_NAME = 'Ido'


class III:
    ISO_639_1 = ''
    ISO_639 = 'iii'
    ENGLISH_NAME = 'SichuanYi'


class IKU:
    ISO_639_1 = ''
    ISO_639 = 'iku'
    ENGLISH_NAME = 'Inuktitut'


class ILE:
    ISO_639_1 = ''
    ISO_639 = 'ile'
    ENGLISH_NAME = 'Interlingue'


class ILO:
    ISO_639_1 = ''
    ISO_639 = 'ilo'
    ENGLISH_NAME = 'Iloko'


class INA:
    ISO_639_1 = ''
    ISO_639 = 'ina'
    ENGLISH_NAME = 'Interlingua'


class IND:
    ISO_639_1 = 'id'
    ISO_639 = 'ind'
    ENGLISH_NAME = 'Indonesian'


class INH:
    ISO_639_1 = ''
    ISO_639 = 'inh'
    ENGLISH_NAME = 'Ingush'


class IPK:
    ISO_639_1 = ''
    ISO_639 = 'ipk'
    ENGLISH_NAME = 'Inupiaq'


class ITA:
    ISO_639_1 = ''
    ISO_639 = 'ita'
    ENGLISH_NAME = 'Italian'


class JAV:
    ISO_639_1 = ''
    ISO_639 = 'jav'
    ENGLISH_NAME = 'Javanese'


class JBO:
    ISO_639_1 = ''
    ISO_639 = 'jbo'
    ENGLISH_NAME = 'Lojban'


class JPN:
    ISO_639_1 = 'ja'
    ISO_639 = 'jpn'
    ENGLISH_NAME = 'Japanese'


class JPR:
    ISO_639_1 = ''
    ISO_639 = 'jpr'
    ENGLISH_NAME = 'JudeoPersian'


class JRB:
    ISO_639_1 = ''
    ISO_639 = 'jrb'
    ENGLISH_NAME = 'JudeoArabic'


class KAA:
    ISO_639_1 = ''
    ISO_639 = 'kaa'
    ENGLISH_NAME = 'KaraKalpak'


class KAB:
    ISO_639_1 = ''
    ISO_639 = 'kab'
    ENGLISH_NAME = 'Kabyle'


class KAC:
    ISO_639_1 = ''
    ISO_639 = 'kac'
    ENGLISH_NAME = 'Kachin'


class KAL:
    ISO_639_1 = ''
    ISO_639 = 'kal'
    ENGLISH_NAME = 'Kalaallisut'


class KAM:
    ISO_639_1 = ''
    ISO_639 = 'kam'
    ENGLISH_NAME = 'Kamba'


class KAN:
    ISO_639_1 = ''
    ISO_639 = 'kan'
    ENGLISH_NAME = 'Kannada'


class KAS:
    ISO_639_1 = ''
    ISO_639 = 'kas'
    ENGLISH_NAME = 'Kashmiri'


class KAU:
    ISO_639_1 = ''
    ISO_639 = 'kau'
    ENGLISH_NAME = 'Kanuri'


class KAW:
    ISO_639_1 = ''
    ISO_639 = 'kaw'
    ENGLISH_NAME = 'Kawi'


class KAZ:
    ISO_639_1 = ''
    ISO_639 = 'kaz'
    ENGLISH_NAME = 'Kazakh'


class KBD:
    ISO_639_1 = ''
    ISO_639 = 'kbd'
    ENGLISH_NAME = 'Kabardian'


class KHA:
    ISO_639_1 = ''
    ISO_639 = 'kha'
    ENGLISH_NAME = 'Khasi'


class KHM:
    ISO_639_1 = ''
    ISO_639 = 'khm'
    ENGLISH_NAME = 'CentralKhmer'


class KHO:
    ISO_639_1 = ''
    ISO_639 = 'kho'
    ENGLISH_NAME = 'Khotanese'


class KIK:
    ISO_639_1 = ''
    ISO_639 = 'kik'
    ENGLISH_NAME = 'Kikuyu'


class KIN:
    ISO_639_1 = ''
    ISO_639 = 'kin'
    ENGLISH_NAME = 'Kinyarwanda'


class KIR:
    ISO_639_1 = ''
    ISO_639 = 'kir'
    ENGLISH_NAME = 'Kirghiz'


class KMB:
    ISO_639_1 = ''
    ISO_639 = 'kmb'
    ENGLISH_NAME = 'Kimbundu'


class KOK:
    ISO_639_1 = ''
    ISO_639 = 'kok'
    ENGLISH_NAME = 'Konkani'


class KOM:
    ISO_639_1 = ''
    ISO_639 = 'kom'
    ENGLISH_NAME = 'Komi'


class KON:
    ISO_639_1 = ''
    ISO_639 = 'kon'
    ENGLISH_NAME = 'Kongo'


class KOR:
    ISO_639_1 = 'ko'
    ISO_639 = 'kor'
    ENGLISH_NAME = 'Korean'


class KOS:
    ISO_639_1 = ''
    ISO_639 = 'kos'
    ENGLISH_NAME = 'Kosraean'


class KPE:
    ISO_639_1 = ''
    ISO_639 = 'kpe'
    ENGLISH_NAME = 'Kpelle'


class KRC:
    ISO_639_1 = ''
    ISO_639 = 'krc'
    ENGLISH_NAME = 'KarachayBalkar'


class KRL:
    ISO_639_1 = ''
    ISO_639 = 'krl'
    ENGLISH_NAME = 'Karelian'


class KRU:
    ISO_639_1 = ''
    ISO_639 = 'kru'
    ENGLISH_NAME = 'Kurukh'


class KUA:
    ISO_639_1 = ''
    ISO_639 = 'kua'
    ENGLISH_NAME = 'Kuanyama'


class KUM:
    ISO_639_1 = ''
    ISO_639 = 'kum'
    ENGLISH_NAME = 'Kumyk'


class KUR:
    ISO_639_1 = ''
    ISO_639 = 'kur'
    ENGLISH_NAME = 'Kurdish'


class KUT:
    ISO_639_1 = ''
    ISO_639 = 'kut'
    ENGLISH_NAME = 'Kutenai'


class LAD:
    ISO_639_1 = ''
    ISO_639 = 'lad'
    ENGLISH_NAME = 'Ladino'


class LAH:
    ISO_639_1 = ''
    ISO_639 = 'lah'
    ENGLISH_NAME = 'Lahnda'


class LAM:
    ISO_639_1 = ''
    ISO_639 = 'lam'
    ENGLISH_NAME = 'Lamba'


class LAO:
    ISO_639_1 = ''
    ISO_639 = 'lao'
    ENGLISH_NAME = 'Lao'


class LAT:
    ISO_639_1 = ''
    ISO_639 = 'lat'
    ENGLISH_NAME = 'Latin'


class LAV:
    ISO_639_1 = ''
    ISO_639 = 'lav'
    ENGLISH_NAME = 'Latvian'


class LEZ:
    ISO_639_1 = ''
    ISO_639 = 'lez'
    ENGLISH_NAME = 'Lezghian'


class LIM:
    ISO_639_1 = ''
    ISO_639 = 'lim'
    ENGLISH_NAME = 'Limburgan'


class LIN:
    ISO_639_1 = ''
    ISO_639 = 'lin'
    ENGLISH_NAME = 'Lingala'


class LIT:
    ISO_639_1 = ''
    ISO_639 = 'lit'
    ENGLISH_NAME = 'Lithuanian'


class LOL:
    ISO_639_1 = ''
    ISO_639 = 'lol'
    ENGLISH_NAME = 'Mongo'


class LOZ:
    ISO_639_1 = ''
    ISO_639 = 'loz'
    ENGLISH_NAME = 'Lozi'


class LTZ:
    ISO_639_1 = ''
    ISO_639 = 'ltz'
    ENGLISH_NAME = 'Luxembourgish'


class LUA:
    ISO_639_1 = ''
    ISO_639 = 'lua'
    ENGLISH_NAME = 'LubaLulua'


class LUB:
    ISO_639_1 = ''
    ISO_639 = 'lub'
    ENGLISH_NAME = 'LubaKatanga'


class LUG:
    ISO_639_1 = ''
    ISO_639 = 'lug'
    ENGLISH_NAME = 'Ganda'


class LUI:
    ISO_639_1 = ''
    ISO_639 = 'lui'
    ENGLISH_NAME = 'Luiseno'


class LUN:
    ISO_639_1 = ''
    ISO_639 = 'lun'
    ENGLISH_NAME = 'Lunda'


class LUO:
    ISO_639_1 = ''
    ISO_639 = 'luo'
    ENGLISH_NAME = 'Luo'


class LUS:
    ISO_639_1 = ''
    ISO_639 = 'lus'
    ENGLISH_NAME = 'Lushai'


class MAC:
    ISO_639_1 = ''
    ISO_639 = 'mac'
    ENGLISH_NAME = 'Macedonian'


class MAD:
    ISO_639_1 = ''
    ISO_639 = 'mad'
    ENGLISH_NAME = 'Madurese'


class MAG:
    ISO_639_1 = ''
    ISO_639 = 'mag'
    ENGLISH_NAME = 'Magahi'


class MAH:
    ISO_639_1 = ''
    ISO_639 = 'mah'
    ENGLISH_NAME = 'Marshallese'


class MAI:
    ISO_639_1 = ''
    ISO_639 = 'mai'
    ENGLISH_NAME = 'Maithili'


class MAK:
    ISO_639_1 = ''
    ISO_639 = 'mak'
    ENGLISH_NAME = 'Makasar'


class MAL:
    ISO_639_1 = ''
    ISO_639 = 'mal'
    ENGLISH_NAME = 'Malayalam'


class MAN:
    ISO_639_1 = ''
    ISO_639 = 'man'
    ENGLISH_NAME = 'Mandingo'


class MAO:
    ISO_639_1 = ''
    ISO_639 = 'mao'
    ENGLISH_NAME = 'Maori'


class MAR:
    ISO_639_1 = 'mr'
    ISO_639 = 'mar'
    ENGLISH_NAME = 'Marathi'


class MAS:
    ISO_639_1 = ''
    ISO_639 = 'mas'
    ENGLISH_NAME = 'Masai'


class MAY:
    ISO_639_1 = ''
    ISO_639 = 'may'
    ENGLISH_NAME = 'Malay'


class MDF:
    ISO_639_1 = ''
    ISO_639 = 'mdf'
    ENGLISH_NAME = 'Moksha'


class MDR:
    ISO_639_1 = ''
    ISO_639 = 'mdr'
    ENGLISH_NAME = 'Mandar'


class MEN:
    ISO_639_1 = ''
    ISO_639 = 'men'
    ENGLISH_NAME = 'Mende'


class MIC:
    ISO_639_1 = ''
    ISO_639 = 'mic'
    ENGLISH_NAME = 'Mikmaq'


class MIN:
    ISO_639_1 = ''
    ISO_639 = 'min'
    ENGLISH_NAME = 'Minangkabau'


class MLG:
    ISO_639_1 = ''
    ISO_639 = 'mlg'
    ENGLISH_NAME = 'Malagasy'


class MLT:
    ISO_639_1 = ''
    ISO_639 = 'mlt'
    ENGLISH_NAME = 'Maltese'


class MNC:
    ISO_639_1 = ''
    ISO_639 = 'mnc'
    ENGLISH_NAME = 'Manchu'


class MNI:
    ISO_639_1 = ''
    ISO_639 = 'mni'
    ENGLISH_NAME = 'Manipuri'


class MOH:
    ISO_639_1 = ''
    ISO_639 = 'moh'
    ENGLISH_NAME = 'Mohawk'


class MON:
    ISO_639_1 = ''
    ISO_639 = 'mon'
    ENGLISH_NAME = 'Mongolian'


class MOS:
    ISO_639_1 = ''
    ISO_639 = 'mos'
    ENGLISH_NAME = 'Mossi'


class MUS:
    ISO_639_1 = ''
    ISO_639 = 'mus'
    ENGLISH_NAME = 'Creek'


class MWL:
    ISO_639_1 = ''
    ISO_639 = 'mwl'
    ENGLISH_NAME = 'Mirandese'


class MWR:
    ISO_639_1 = ''
    ISO_639 = 'mwr'
    ENGLISH_NAME = 'Marwari'


class MYV:
    ISO_639_1 = ''
    ISO_639 = 'myv'
    ENGLISH_NAME = 'Erzya'


class NAP:
    ISO_639_1 = ''
    ISO_639 = 'nap'
    ENGLISH_NAME = 'Neapolitan'


class NAU:
    ISO_639_1 = ''
    ISO_639 = 'nau'
    ENGLISH_NAME = 'Nauru'


class NAV:
    ISO_639_1 = ''
    ISO_639 = 'nav'
    ENGLISH_NAME = 'Navajo'


class NBL:
    ISO_639_1 = ''
    ISO_639 = 'nbl'
    ENGLISH_NAME = 'Ndebele'


class NDE:
    ISO_639_1 = ''
    ISO_639 = 'nde'
    ENGLISH_NAME = 'Ndebele'


class NDO:
    ISO_639_1 = ''
    ISO_639 = 'ndo'
    ENGLISH_NAME = 'Ndonga'


class NEP:
    ISO_639_1 = ''
    ISO_639 = 'nep'
    ENGLISH_NAME = 'Nepali'


class NEW:
    ISO_639_1 = ''
    ISO_639 = 'new'
    ENGLISH_NAME = 'NepalBhasa'


class NIA:
    ISO_639_1 = ''
    ISO_639 = 'nia'
    ENGLISH_NAME = 'Nias'


class NIU:
    ISO_639_1 = ''
    ISO_639 = 'niu'
    ENGLISH_NAME = 'Niuean'


class NNO:
    ISO_639_1 = ''
    ISO_639 = 'nno'
    ENGLISH_NAME = 'NorwegianNynorsk'


class NOB:
    ISO_639_1 = ''
    ISO_639 = 'nob'
    ENGLISH_NAME = 'Bokmål'


class NOG:
    ISO_639_1 = ''
    ISO_639 = 'nog'
    ENGLISH_NAME = 'Nogai'


class NOR:
    ISO_639_1 = ''
    ISO_639 = 'nor'
    ENGLISH_NAME = 'Norwegian'


class NQO:
    ISO_639_1 = ''
    ISO_639 = 'nqo'
    ENGLISH_NAME = 'NKo'


class NSO:
    ISO_639_1 = ''
    ISO_639 = 'nso'
    ENGLISH_NAME = 'Pedi'


class NYA:
    ISO_639_1 = ''
    ISO_639 = 'nya'
    ENGLISH_NAME = 'Chichewa'


class NYM:
    ISO_639_1 = ''
    ISO_639 = 'nym'
    ENGLISH_NAME = 'Nyamwezi'


class NYN:
    ISO_639_1 = ''
    ISO_639 = 'nyn'
    ENGLISH_NAME = 'Nyankole'


class NYO:
    ISO_639_1 = ''
    ISO_639 = 'nyo'
    ENGLISH_NAME = 'Nyoro'


class NZI:
    ISO_639_1 = ''
    ISO_639 = 'nzi'
    ENGLISH_NAME = 'Nzima'


class OJI:
    ISO_639_1 = ''
    ISO_639 = 'oji'
    ENGLISH_NAME = 'Ojibwa'


class ORI:
    ISO_639_1 = 'or'
    ISO_639 = 'ori'
    ENGLISH_NAME = 'Oriya'


class ORM:
    ISO_639_1 = ''
    ISO_639 = 'orm'
    ENGLISH_NAME = 'Oromo'


class OSA:
    ISO_639_1 = ''
    ISO_639 = 'osa'
    ENGLISH_NAME = 'Osage'


class OSS:
    ISO_639_1 = ''
    ISO_639 = 'oss'
    ENGLISH_NAME = 'Ossetian'


class PAG:
    ISO_639_1 = ''
    ISO_639 = 'pag'
    ENGLISH_NAME = 'Pangasinan'


class PAL:
    ISO_639_1 = ''
    ISO_639 = 'pal'
    ENGLISH_NAME = 'Pahlavi'


class PAM:
    ISO_639_1 = ''
    ISO_639 = 'pam'
    ENGLISH_NAME = 'Pampanga'


class PAN:
    ISO_639_1 = ''
    ISO_639 = 'pan'
    ENGLISH_NAME = 'Panjabi'


class PAP:
    ISO_639_1 = ''
    ISO_639 = 'pap'
    ENGLISH_NAME = 'Papiamento'


class PAU:
    ISO_639_1 = ''
    ISO_639 = 'pau'
    ENGLISH_NAME = 'Palauan'


class PER:
    ISO_639_1 = 'fa'
    ISO_639 = 'per'
    ENGLISH_NAME = 'Persian'


class PHN:
    ISO_639_1 = ''
    ISO_639 = 'phn'
    ENGLISH_NAME = 'Phoenician'


class PLI:
    ISO_639_1 = ''
    ISO_639 = 'pli'
    ENGLISH_NAME = 'Pali'


class POL:
    ISO_639_1 = ''
    ISO_639 = 'pol'
    ENGLISH_NAME = 'Polish'


class PON:
    ISO_639_1 = ''
    ISO_639 = 'pon'
    ENGLISH_NAME = 'Pohnpeian'


class POR:
    ISO_639_1 = 'pt'
    ISO_639 = 'por'
    ENGLISH_NAME = 'Portuguese'


class PUS:
    ISO_639_1 = ''
    ISO_639 = 'pus'
    ENGLISH_NAME = 'Pushto'


class QUE:
    ISO_639_1 = ''
    ISO_639 = 'que'
    ENGLISH_NAME = 'Quechua'


class RAJ:
    ISO_639_1 = ''
    ISO_639 = 'raj'
    ENGLISH_NAME = 'Rajasthani'


class RAP:
    ISO_639_1 = ''
    ISO_639 = 'rap'
    ENGLISH_NAME = 'Rapanui'


class RAR:
    ISO_639_1 = ''
    ISO_639 = 'rar'
    ENGLISH_NAME = 'Rarotongan'


class ROH:
    ISO_639_1 = ''
    ISO_639 = 'roh'
    ENGLISH_NAME = 'Romansh'


class ROM:
    ISO_639_1 = ''
    ISO_639 = 'rom'
    ENGLISH_NAME = 'Romany'


class RUM:
    ISO_639_1 = ''
    ISO_639 = 'rum'
    ENGLISH_NAME = 'Romanian'


class RUN:
    ISO_639_1 = ''
    ISO_639 = 'run'
    ENGLISH_NAME = 'Rundi'


class RUP:
    ISO_639_1 = ''
    ISO_639 = 'rup'
    ENGLISH_NAME = 'Aromanian'


class RUS:
    ISO_639_1 = 'ru'
    ISO_639 = 'rus'
    ENGLISH_NAME = 'Russian'


class SAD:
    ISO_639_1 = ''
    ISO_639 = 'sad'
    ENGLISH_NAME = 'Sandawe'


class SAG:
    ISO_639_1 = ''
    ISO_639 = 'sag'
    ENGLISH_NAME = 'Sango'


class SAH:
    ISO_639_1 = ''
    ISO_639 = 'sah'
    ENGLISH_NAME = 'Yakut'


class SAM:
    ISO_639_1 = ''
    ISO_639 = 'sam'
    ENGLISH_NAME = 'SamaritanAramaic'


class SAN:
    ISO_639_1 = ''
    ISO_639 = 'san'
    ENGLISH_NAME = 'Sanskrit'


class SAS:
    ISO_639_1 = ''
    ISO_639 = 'sas'
    ENGLISH_NAME = 'Sasak'


class SAT:
    ISO_639_1 = ''
    ISO_639 = 'sat'
    ENGLISH_NAME = 'Santali'


class SCN:
    ISO_639_1 = ''
    ISO_639 = 'scn'
    ENGLISH_NAME = 'Sicilian'


class SCO:
    ISO_639_1 = ''
    ISO_639 = 'sco'
    ENGLISH_NAME = 'Scots'


class SEL:
    ISO_639_1 = ''
    ISO_639 = 'sel'
    ENGLISH_NAME = 'Selkup'


class SHN:
    ISO_639_1 = ''
    ISO_639 = 'shn'
    ENGLISH_NAME = 'Shan'


class SID:
    ISO_639_1 = ''
    ISO_639 = 'sid'
    ENGLISH_NAME = 'Sidamo'


class SIN:
    ISO_639_1 = ''
    ISO_639 = 'sin'
    ENGLISH_NAME = 'Sinhala'


class SLO:
    ISO_639_1 = ''
    ISO_639 = 'slo'
    ENGLISH_NAME = 'Slovak'


class SLV:
    ISO_639_1 = ''
    ISO_639 = 'slv'
    ENGLISH_NAME = 'Slovenian'


class SMA:
    ISO_639_1 = ''
    ISO_639 = 'sma'
    ENGLISH_NAME = 'SouthernSami'


class SME:
    ISO_639_1 = ''
    ISO_639 = 'sme'
    ENGLISH_NAME = 'NorthernSami'


class SMJ:
    ISO_639_1 = ''
    ISO_639 = 'smj'
    ENGLISH_NAME = 'LuleSami'


class SMN:
    ISO_639_1 = ''
    ISO_639 = 'smn'
    ENGLISH_NAME = 'InariSami'


class SMO:
    ISO_639_1 = ''
    ISO_639 = 'smo'
    ENGLISH_NAME = 'Samoan'


class SMS:
    ISO_639_1 = ''
    ISO_639 = 'sms'
    ENGLISH_NAME = 'SkoltSami'


class SNA:
    ISO_639_1 = ''
    ISO_639 = 'sna'
    ENGLISH_NAME = 'Shona'


class SND:
    ISO_639_1 = ''
    ISO_639 = 'snd'
    ENGLISH_NAME = 'Sindhi'


class SNK:
    ISO_639_1 = ''
    ISO_639 = 'snk'
    ENGLISH_NAME = 'Soninke'


class SOG:
    ISO_639_1 = ''
    ISO_639 = 'sog'
    ENGLISH_NAME = 'Sogdian'


class SOM:
    ISO_639_1 = ''
    ISO_639 = 'som'
    ENGLISH_NAME = 'Somali'


class SOT:
    ISO_639_1 = ''
    ISO_639 = 'sot'
    ENGLISH_NAME = 'Sotho'


class SPA:
    ISO_639_1 = 'es'
    ISO_639 = 'spa'
    ENGLISH_NAME = 'Spanish'


class SRD:
    ISO_639_1 = ''
    ISO_639 = 'srd'
    ENGLISH_NAME = 'Sardinian'


class SRN:
    ISO_639_1 = ''
    ISO_639 = 'srn'
    ENGLISH_NAME = 'SrananTongo'


class SRP:
    ISO_639_1 = ''
    ISO_639 = 'srp'
    ENGLISH_NAME = 'Serbian'


class SRR:
    ISO_639_1 = ''
    ISO_639 = 'srr'
    ENGLISH_NAME = 'Serer'


class SSW:
    ISO_639_1 = ''
    ISO_639 = 'ssw'
    ENGLISH_NAME = 'Swati'


class SUK:
    ISO_639_1 = ''
    ISO_639 = 'suk'
    ENGLISH_NAME = 'Sukuma'


class SUN:
    ISO_639_1 = ''
    ISO_639 = 'sun'
    ENGLISH_NAME = 'Sundanese'


class SUS:
    ISO_639_1 = ''
    ISO_639 = 'sus'
    ENGLISH_NAME = 'Susu'


class SUX:
    ISO_639_1 = ''
    ISO_639 = 'sux'
    ENGLISH_NAME = 'Sumerian'


class SWA:
    ISO_639_1 = ''
    ISO_639 = 'swa'
    ENGLISH_NAME = 'Swahili'


class SWE:
    ISO_639_1 = 'sv'
    ISO_639 = 'swe'
    ENGLISH_NAME = 'Swedish'


class SYC:
    ISO_639_1 = ''
    ISO_639 = 'syc'
    ENGLISH_NAME = 'ClassicalSyriac'


class SYR:
    ISO_639_1 = ''
    ISO_639 = 'syr'
    ENGLISH_NAME = 'Syriac'


class TAH:
    ISO_639_1 = 'th'
    ISO_639 = 'tah'
    ENGLISH_NAME = 'Tahitian'


class TAM:
    ISO_639_1 = ''
    ISO_639 = 'tam'
    ENGLISH_NAME = 'Tamil'


class TAT:
    ISO_639_1 = ''
    ISO_639 = 'tat'
    ENGLISH_NAME = 'Tatar'


class TEL:
    ISO_639_1 = 'te'
    ISO_639 = 'tel'
    ENGLISH_NAME = 'Telugu'


class TEM:
    ISO_639_1 = ''
    ISO_639 = 'tem'
    ENGLISH_NAME = 'Timne'


class TER:
    ISO_639_1 = ''
    ISO_639 = 'ter'
    ENGLISH_NAME = 'Tereno'


class TET:
    ISO_639_1 = ''
    ISO_639 = 'tet'
    ENGLISH_NAME = 'Tetum'


class TGK:
    ISO_639_1 = ''
    ISO_639 = 'tgk'
    ENGLISH_NAME = 'Tajik'


class TGL:
    ISO_639_1 = ''
    ISO_639 = 'tgl'
    ENGLISH_NAME = 'Tagalog'


class THA:
    ISO_639_1 = ''
    ISO_639 = 'tha'
    ENGLISH_NAME = 'Thai'


class TIB:
    ISO_639_1 = ''
    ISO_639 = 'tib'
    ENGLISH_NAME = 'Tibetan'


class TIG:
    ISO_639_1 = ''
    ISO_639 = 'tig'
    ENGLISH_NAME = 'Tigre'


class TIR:
    ISO_639_1 = ''
    ISO_639 = 'tir'
    ENGLISH_NAME = 'Tigrinya'


class TIV:
    ISO_639_1 = ''
    ISO_639 = 'tiv'
    ENGLISH_NAME = 'Tiv'


class TKL:
    ISO_639_1 = ''
    ISO_639 = 'tkl'
    ENGLISH_NAME = 'Tokelau'


class TLH:
    ISO_639_1 = ''
    ISO_639 = 'tlh'
    ENGLISH_NAME = 'Klingon'


class TLI:
    ISO_639_1 = ''
    ISO_639 = 'tli'
    ENGLISH_NAME = 'Tlingit'


class TMH:
    ISO_639_1 = ''
    ISO_639 = 'tmh'
    ENGLISH_NAME = 'Tamashek'


class TOG:
    ISO_639_1 = ''
    ISO_639 = 'tog'
    ENGLISH_NAME = 'Tonga'


class TON:
    ISO_639_1 = ''
    ISO_639 = 'ton'
    ENGLISH_NAME = 'Tonga'


class TPI:
    ISO_639_1 = ''
    ISO_639 = 'tpi'
    ENGLISH_NAME = 'TokPisin'


class TSI:
    ISO_639_1 = ''
    ISO_639 = 'tsi'
    ENGLISH_NAME = 'Tsimshian'


class TSN:
    ISO_639_1 = ''
    ISO_639 = 'tsn'
    ENGLISH_NAME = 'Tswana'


class TSO:
    ISO_639_1 = ''
    ISO_639 = 'tso'
    ENGLISH_NAME = 'Tsonga'


class TUK:
    ISO_639_1 = ''
    ISO_639 = 'tuk'
    ENGLISH_NAME = 'Turkmen'


class TUM:
    ISO_639_1 = ''
    ISO_639 = 'tum'
    ENGLISH_NAME = 'Tumbuka'


class TUR:
    ISO_639_1 = ''
    ISO_639 = 'tur'
    ENGLISH_NAME = 'Turkish'


class TVL:
    ISO_639_1 = ''
    ISO_639 = 'tvl'
    ENGLISH_NAME = 'Tuvalu'


class TWI:
    ISO_639_1 = ''
    ISO_639 = 'twi'
    ENGLISH_NAME = 'Twi'


class TYV:
    ISO_639_1 = ''
    ISO_639 = 'tyv'
    ENGLISH_NAME = 'Tuvinian'


class UDM:
    ISO_639_1 = ''
    ISO_639 = 'udm'
    ENGLISH_NAME = 'Udmurt'


class UGA:
    ISO_639_1 = ''
    ISO_639 = 'uga'
    ENGLISH_NAME = 'Ugaritic'


class UIG:
    ISO_639_1 = ''
    ISO_639 = 'uig'
    ENGLISH_NAME = 'Uighur'


class UKR:
    ISO_639_1 = ''
    ISO_639 = 'ukr'
    ENGLISH_NAME = 'Ukrainian'


class UMB:
    ISO_639_1 = ''
    ISO_639 = 'umb'
    ENGLISH_NAME = 'Umbundu'


class UND:
    ISO_639_1 = ''
    ISO_639 = 'und'
    ENGLISH_NAME = 'Undetermined'


class URD:
    ISO_639_1 = ''
    ISO_639 = 'urd'
    ENGLISH_NAME = 'Urdu'


class UZB:
    ISO_639_1 = ''
    ISO_639 = 'uzb'
    ENGLISH_NAME = 'Uzbek'


class VAI:
    ISO_639_1 = ''
    ISO_639 = 'vai'
    ENGLISH_NAME = 'Vai'


class VEN:
    ISO_639_1 = ''
    ISO_639 = 'ven'
    ENGLISH_NAME = 'Venda'


class VIE:
    ISO_639_1 = ''
    ISO_639 = 'vie'
    ENGLISH_NAME = 'Vietnamese'


class VOL:
    ISO_639_1 = ''
    ISO_639 = 'vol'
    ENGLISH_NAME = 'Volapük'


class VOT:
    ISO_639_1 = ''
    ISO_639 = 'vot'
    ENGLISH_NAME = 'Votic'


class WAL:
    ISO_639_1 = ''
    ISO_639 = 'wal'
    ENGLISH_NAME = 'Wolaitta'


class WAR:
    ISO_639_1 = ''
    ISO_639 = 'war'
    ENGLISH_NAME = 'Waray'


class WAS:
    ISO_639_1 = ''
    ISO_639 = 'was'
    ENGLISH_NAME = 'Washo'


class WEL:
    ISO_639_1 = ''
    ISO_639 = 'wel'
    ENGLISH_NAME = 'Welsh'


class WLN:
    ISO_639_1 = ''
    ISO_639 = 'wln'
    ENGLISH_NAME = 'Walloon'


class WOL:
    ISO_639_1 = ''
    ISO_639 = 'wol'
    ENGLISH_NAME = 'Wolof'


class XAL:
    ISO_639_1 = ''
    ISO_639 = 'xal'
    ENGLISH_NAME = 'Kalmyk'


class XHO:
    ISO_639_1 = ''
    ISO_639 = 'xho'
    ENGLISH_NAME = 'Xhosa'


class YAO:
    ISO_639_1 = ''
    ISO_639 = 'yao'
    ENGLISH_NAME = 'Yao'


class YAP:
    ISO_639_1 = ''
    ISO_639 = 'yap'
    ENGLISH_NAME = 'Yapese'


class YID:
    ISO_639_1 = ''
    ISO_639 = 'yid'
    ENGLISH_NAME = 'Yiddish'


class YOR:
    ISO_639_1 = ''
    ISO_639 = 'yor'
    ENGLISH_NAME = 'Yoruba'


class ZAP:
    ISO_639_1 = ''
    ISO_639 = 'zap'
    ENGLISH_NAME = 'Zapotec'


class ZBL:
    ISO_639_1 = ''
    ISO_639 = 'zbl'
    ENGLISH_NAME = 'Blissymbols'


class ZEN:
    ISO_639_1 = ''
    ISO_639 = 'zen'
    ENGLISH_NAME = 'Zenaga'


class ZGH:
    ISO_639_1 = ''
    ISO_639 = 'zgh'
    ENGLISH_NAME = 'StandardMoroccanTamazight'


class ZHA:
    ISO_639_1 = ''
    ISO_639 = 'zha'
    ENGLISH_NAME = 'Zhuang'


class ZHS:
    ISO_639_1 = ''
    ISO_639 = 'zhs'
    ENGLISH_NAME = 'SimplifiedChinese'


class ZHT:
    ISO_639_1 = ''
    ISO_639 = 'zht'
    ENGLISH_NAME = 'TraditionalChinese'


class ZUL:
    ISO_639_1 = ''
    ISO_639 = 'zul'
    ENGLISH_NAME = 'Zulu'


class ZUN:
    ISO_639_1 = ''
    ISO_639 = 'zun'
    ENGLISH_NAME = 'Zuni'


class ZZA:
    ISO_639_1 = ''
    ISO_639 = 'zza'
    ENGLISH_NAME = 'Zaza'


def get_language_classes():
    import sys
    import inspect

    return inspect.getmembers(sys.modules[__name__], inspect.isclass)



from pytz import UTC
from datetime import datetime
from dateutil import parser as date_parser


class StatementMixin(object):
    """
    This class has shared methods used to
    normalize different statement models.
    """

    statement_field_names = [
        'id',
        'text',
        'search_text',
        'conversation',
        'persona',
        'tags',
        'in_response_to',
        'search_in_response_to',
        'created_at',
    ]

    extra_statement_field_names = []

    def get_statement_field_names(self):
        """
        Return the list of field names for the statement.
        """
        return self.statement_field_names + self.extra_statement_field_names

    def get_tags(self):
        """
        Return the list of tags for this statement.
        """
        return self.tags

    def add_tags(self, *tags):
        """
        Add a list of strings to the statement as tags.
        """
        self.tags.extend(tags)

    def serialize(self):
        """
        :returns: A dictionary representation of the statement object.
        :rtype: dict
        """
        data = {}

        for field_name in self.get_statement_field_names():
            format_method = getattr(self, 'get_{}'.format(
                field_name
            ), None)

            if format_method:
                data[field_name] = format_method()
            else:
                data[field_name] = getattr(self, field_name)

        return data


class Statement(StatementMixin):
    """
    A statement represents a single spoken entity, sentence or
    phrase that someone can say.
    """

    __slots__ = (
        'id',
        'text',
        'search_text',
        'conversation',
        'persona',
        'tags',
        'in_response_to',
        'search_in_response_to',
        'created_at',
        'confidence',
        'storage',
    )

    def __init__(self, text, in_response_to=None, **kwargs):

        self.id = kwargs.get('id')
        self.text = str(text)
        self.search_text = kwargs.get('search_text', '')
        self.conversation = kwargs.get('conversation', '')
        self.persona = kwargs.get('persona', '')
        self.tags = kwargs.pop('tags', [])
        self.in_response_to = in_response_to
        self.search_in_response_to = kwargs.get('search_in_response_to', '')
        self.created_at = kwargs.get('created_at', datetime.now())

        if not isinstance(self.created_at, datetime):
            self.created_at = date_parser.parse(self.created_at)

        # Set timezone to UTC if no timezone was provided
        if not self.created_at.tzinfo:
            self.created_at = self.created_at.replace(tzinfo=UTC)

        # This is the confidence with which the chat bot believes
        # this is an accurate response. This value is set when the
        # statement is returned by the chat bot.
        self.confidence = 0

        self.storage = None

    def __str__(self):
        return self.text

    def __repr__(self):
        return '<Statement text:%s>' % (self.text)

    def save(self):
        """
        Save the statement in the database.
        """
        self.storage.update(self)



#!/usr/bin/env python
"""
ChatterBot setup file.
"""
import os
import sys
import platform
import configparser
from setuptools import setup


if sys.version_info[0] < 3:
    raise Exception(
        'You are tying to install ChatterBot on Python version {}.\n'
        'Please install ChatterBot in Python 3 instead.'.format(
            platform.python_version()
        )
    )

config = configparser.ConfigParser()

current_directory = os.path.dirname(os.path.abspath(__file__))
config_file_path = os.path.join(current_directory, 'setup.cfg')

config.read(config_file_path)

VERSION = config['chatterbot']['version']
AUTHOR = config['chatterbot']['author']
AUTHOR_EMAIL = config['chatterbot']['email']
URL = config['chatterbot']['url']

with open('README.md') as f:
    LONG_DESCRIPTION = f.read()

REQUIREMENTS = []
DEPENDENCIES = []

with open('requirements.txt') as requirements:
    for requirement in requirements.readlines():
        if requirement.startswith('git+git://'):
            DEPENDENCIES.append(requirement)
        else:
            REQUIREMENTS.append(requirement)


setup(
    name='sugaroid-chatterBot',
    version=VERSION,
    url=URL,
    download_url='{}/tarball/{}'.format(URL, VERSION),
    project_urls={
        'Documentation': 'https://chatterbot.readthedocs.io',
    },
    description='ChatterBot is a machine learning, conversational dialog engine optimized for Sugaroid bot.',
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    packages=[
        'chatterbot',
        'chatterbot.storage',
        'chatterbot.logic',
        'chatterbot.ext',
        'chatterbot.ext.sqlalchemy_app',
        'chatterbot.ext.django_chatterbot',
        'chatterbot.ext.django_chatterbot.migrations',
    ],
    package_dir={'chatterbot': 'chatterbot'},
    include_package_data=True,
    install_requires=REQUIREMENTS,
    dependency_links=DEPENDENCIES,
    python_requires='>=3.4, <4',
    license='BSD',
    zip_safe=True,
    platforms=['any'],
    keywords=['ChatterBot', 'chatbot', 'chat', 'bot'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Environment :: Console',
        'Environment :: Web Environment',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Communications :: Chat',
        'Topic :: Internet',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3 :: Only',
    ],
    test_suite='tests'
)



# Generated by Django 1.9 on 2017-01-17 07:02
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('django_chatterbot', '0005_statement_created_at'),
    ]

    operations = [
        migrations.CreateModel(
            name='Conversation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
            ],
        ),
        migrations.AlterField(
            model_name='statement',
            name='created_at',
            field=models.DateTimeField(default=django.utils.timezone.now, help_text='The date and time that this statement was created at.'),
        ),
        migrations.AddField(
            model_name='conversation',
            name='statements',
            field=models.ManyToManyField(help_text='The statements in this conversation.', related_name='conversation', to='django_chatterbot.Statement'),
        ),
    ]



from chatterbot.logic import LogicAdapter
from chatterbot.conversation import Statement
from chatterbot import languages
from chatterbot import parsing
from mathparse import mathparse
import re


class UnitConversion(LogicAdapter):
    """
    The UnitConversion logic adapter parse inputs to convert values
    between several metric units.

    For example:
        User: 'How many meters are in one kilometer?'
        Bot: '1000.0'

    :kwargs:
        * *language* (``object``) --
        The language is set to ``chatterbot.languages.ENG`` for English by default.
    """

    def __init__(self, chatbot, **kwargs):
        super().__init__(chatbot, **kwargs)
        from pint import UnitRegistry

        self.language = kwargs.get('language', languages.ENG)
        self.cache = {}
        self.patterns = [
            (
                re.compile(r'''
                   (([Hh]ow\s+many)\s+
                   (?P<target>\S+)\s+ # meter, celsius, hours
                   ((are)*\s*in)\s+
                   (?P<number>([+-]?\d+(?:\.\d+)?)|(a|an)|(%s[-\s]?)+)\s+
                   (?P<from>\S+)\s*) # meter, celsius, hours
                   ''' % (parsing.numbers),
                    (re.VERBOSE | re.IGNORECASE)
                ),
                lambda m: self.handle_matches(m)
            ),
            (
                re.compile(r'''
                   ((?P<number>([+-]?\d+(?:\.\d+)?)|(%s[-\s]?)+)\s+
                   (?P<from>\S+)\s+ # meter, celsius, hours
                   (to)\s+
                   (?P<target>\S+)\s*) # meter, celsius, hours
                   ''' % (parsing.numbers),
                    (re.VERBOSE | re.IGNORECASE)
                ),
                lambda m: self.handle_matches(m)
            ),
            (
                re.compile(r'''
                   ((?P<number>([+-]?\d+(?:\.\d+)?)|(a|an)|(%s[-\s]?)+)\s+
                   (?P<from>\S+)\s+ # meter, celsius, hours
                   (is|are)\s+
                   (how\s+many)*\s+
                   (?P<target>\S+)\s*) # meter, celsius, hours
                   ''' % (parsing.numbers),
                    (re.VERBOSE | re.IGNORECASE)
                ),
                lambda m: self.handle_matches(m)
            )
        ]
        self.unit_registry = UnitRegistry()

    def get_unit(self, unit_variations):
        """
        Get the first match unit metric object supported by pint library
        given a variation of unit metric names (Ex:['HOUR', 'hour']).

        :param unit_variations: A list of strings with names of units
        :type unit_variations: str
        """
        for unit in unit_variations:
            try:
                return getattr(self.unit_registry, unit)
            except Exception:
                continue
        return None

    def get_valid_units(self, from_unit, target_unit):
        """
        Returns the firt match `pint.unit.Unit` object for from_unit and
        target_unit strings from a possible variation of metric unit names
        supported by pint library.

        :param from_unit: source metric unit
        :type from_unit: str

        :param from_unit: target metric unit
        :type from_unit: str
        """
        from_unit_variations = [from_unit.lower(), from_unit.upper()]
        target_unit_variations = [target_unit.lower(), target_unit.upper()]
        from_unit = self.get_unit(from_unit_variations)
        target_unit = self.get_unit(target_unit_variations)
        return from_unit, target_unit

    def handle_matches(self, match):
        """
        Returns a response statement from a matched input statement.

        :param match: It is a valid matched pattern from the input statement
        :type: `_sre.SRE_Match`
        """
        response = Statement(text='')

        from_parsed = match.group("from")
        target_parsed = match.group("target")
        n_statement = match.group("number")

        if n_statement == 'a' or n_statement == 'an':
            n_statement = '1.0'

        n = mathparse.parse(n_statement, self.language.ISO_639.upper())

        from_parsed, target_parsed = self.get_valid_units(from_parsed, target_parsed)

        if from_parsed is None or target_parsed is None:
            response.confidence = 0.0
        else:
            from_value = self.unit_registry.Quantity(float(n), from_parsed)
            target_value = from_value.to(target_parsed)
            response.confidence = 1.0
            response.text = str(target_value.magnitude)

        return response

    def can_process(self, statement):
        response = self.process(statement)
        self.cache[statement.text] = response
        return response.confidence == 1.0

    def process(self, statement, additional_response_selection_parameters=None):
        response = Statement(text='')
        input_text = statement.text
        try:
            # Use the result cached by the process method if it exists
            if input_text in self.cache:
                response = self.cache[input_text]
                self.cache = {}
                return response

            for pattern, func in self.patterns:
                p = pattern.match(input_text)
                if p is not None:
                    response = func(p)
                    if response.confidence == 1.0:
                        break
        except Exception:
            response.confidence = 0.0
        finally:
            return response



from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name='Response',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('occurrence', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='Statement',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.CharField(max_length=255, unique=True)),
            ],
        ),
        migrations.AddField(
            model_name='response',
            name='response',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='+', to='django_chatterbot.Statement'),
        ),
        migrations.AddField(
            model_name='response',
            name='statement',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='in_response_to', to='django_chatterbot.Statement'),
        ),
    ]



# Generated by Django 1.11.4 on 2017-08-20 13:55
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_chatterbot', '0010_statement_text'),
    ]

    operations = [
        migrations.AlterField(
            model_name='statement',
            name='extra_data',
            field=models.CharField(blank=True, max_length=500),
        ),
    ]
